EMBJOPR SVN: r580 - in trunk/jsfunit: src/test/java/org/jboss/jopr/jsfunit/as5/app/ear and 4 other directories.
by embjopr-commits@lists.jboss.org
Author: ozizka(a)redhat.com
Date: 2009-07-23 17:21:07 -0400 (Thu, 23 Jul 2009)
New Revision: 580
Added:
trunk/jsfunit/testdata/jbcache/
trunk/jsfunit/testdata/jbcache/JBossCacheTest-by-fdrabek.ear
trunk/jsfunit/testdata/jbcache/JBossCacheTest-service.xml
Modified:
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/AppConstants.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbJoprTestConstants.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/jbcache/JBossCacheTest.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/EmbJoprTestToolkit.java
Log:
* JBossCacheTest - default cache tests implemented.
* EJTT - added convenience methods for tables.
* Added test EAR file for JBoss Cache .
* Added JBossCacheTest-service.xml
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/AppConstants.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/AppConstants.java 2009-07-23 18:24:30 UTC (rev 579)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/AppConstants.java 2009-07-23 21:21:07 UTC (rev 580)
@@ -22,16 +22,10 @@
package org.jboss.jopr.jsfunit;
-public interface AppConstants {
+public interface AppConstants extends EmbJoprTestConstants {
- public static final String SYSPROP_DEPLOY_DIR = "jsfunit.deploy.dir";
- public static final String SYSPROP_TESTDATA_DIR = "jsfunit.testdata";
- public static final String SYSPROP_TEMP_DIR = "jsfunit.tempdir";
- public static String SYSPROP_JBOSS_CONFIG = "jboss.configuration";
- public static String SYSPROP_CARGO_JBOSS_HOME_DIR = "jsfunit.jboss.home.dir";
-
-
+
public enum ResourceTypes {
}
@@ -156,13 +150,9 @@
public static final String EAR_NOT_MALFORMED_APP_FILENAME = "not-malformed-application-xml.ear";
public static final String WAR_FILENAME_MALFORMED_APP = "malformed-web-xml.war";
- // Info table headers
- public static final String LABEL_TRAITS = "Traits";
- public static final String LABEL_NUMERIC_METRICS = "Numeric Metrics";
-
// Test Archives
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbJoprTestConstants.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbJoprTestConstants.java 2009-07-23 18:24:30 UTC (rev 579)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbJoprTestConstants.java 2009-07-23 21:21:07 UTC (rev 580)
@@ -11,11 +11,40 @@
*/
public interface EmbJoprTestConstants {
+ // System properties to configure this testsuite.
+ public static final String SYSPROP_DEPLOY_DIR = "jsfunit.deploy.dir";
+ public static final String SYSPROP_TESTDATA_DIR = "jsfunit.testdata";
+ public static final String SYSPROP_TEMP_DIR = "jsfunit.tempdir";
+ public static String SYSPROP_JBOSS_CONFIG = "jboss.configuration";
+ public static String SYSPROP_CARGO_JBOSS_HOME_DIR = "jsfunit.jboss.home.dir";
+
+
//public static final String AS_NODE_NAME_FORMAT = "JBoss AS 5 (%s)";
public static final String AS_NODE_NAME_FORMAT = "JBoss EAP 5 (%s)";
public static final String LABEL_AS_SERVERS_SUMMARY = "JBoss Application Server";
+
+ // Info table headers.
+ public static final String LABEL_GENERAL_PROPERTIES = "General Properties";
+ public static final String LABEL_TRAITS = "Traits";
+ public static final String LABEL_NUMERIC_METRICS = "Numeric Metrics";
+
+ // Table column headers.
+ public static final String COL_PROP_NAME = "Name";
+ public static final String COL_PROP_VALUE = "Value";
+
+ public static final String COL_RESOURCE_NAME = "Name";
+ public static final String COL_RESOURCE_STATUS = "Status";
+
+
+ // Tabs.
+ public static final String TAB_NAME_SUMMARY = "Summary";
+ public static final String TAB_NAME_CONFIG = "Configuration";
+ public static final String TAB_NAME_METRICS = "Metrics";
+ public static final String TAB_NAME_CONTROL = "Control";
+ public static final String TAB_NAME_CONTENT = "Content";
+
}// interface
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java 2009-07-23 18:24:30 UTC (rev 579)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java 2009-07-23 21:21:07 UTC (rev 580)
@@ -70,7 +70,7 @@
public static Test suite(){
- return new TestSuite(EarStressTest.class);
+ return new TestSuite(ProfileServiceTest.class);
}
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/jbcache/JBossCacheTest.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/jbcache/JBossCacheTest.java 2009-07-23 18:24:30 UTC (rev 579)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/jbcache/JBossCacheTest.java 2009-07-23 21:21:07 UTC (rev 580)
@@ -1,12 +1,20 @@
package org.jboss.jopr.jsfunit.as5.jbcache;
import java.io.IOException;
+import java.util.List;
+import java.util.Properties;
import org.jboss.jopr.jsfunit.ApplicationTestBaseAS5;
+import org.jboss.jopr.jsfunit.exceptions.EmbJoprTestException;
import org.jboss.jopr.jsfunit.exceptions.HtmlElementNotFoundException;
+import org.jboss.jopr.jsfunit.util.EmbJoprTestToolkit.ContentTable;
+import org.jboss.jopr.jsfunit.util.EmbJoprTestToolkit.ContentTableRow;
+import org.jboss.jopr.jsfunit.util.EmbJoprTestToolkit.NavTreeNode;
/**
*
* @author Ondrej Zizka
+ *
+ * JBoss Cache is only present in 'all' JBoss AS profile.
*
* TODO: Implement when JBoss Cache support comes to EmbJopr.
*/
@@ -15,28 +23,156 @@
public final DeployableTypes APP_TYPE = DeployableTypes.JBCACHE;
+ // Cache which is active by default.
+ private static final String DEFAULT_JBCACHE = "jboss.cache:config=ha-partition,service=Cache";
-
- public void testJBossCacheParentNode() throws HtmlElementNotFoundException {
- ejtt.navTree.getNodeByLabel(APP_TYPE.getNavTreeLabel());
- fail("JBoss Cache not present yet.");
+
+ private boolean isJBossConfigWithoutCache(){
+ boolean isJBossConfigWithoutCache = ! ejtt.getJBossConfig().equals("all");
+ if( isJBossConfigWithoutCache )
+ log.warn("JBoss instance is not running the 'all' configuration - has no JBoss Cache. Skipping this test.");
+ return isJBossConfigWithoutCache;
}
+ /**
+ * Test the navigation to JBoss Cache nodes.
+ */
+ public void testJBossCacheParentNode() throws HtmlElementNotFoundException, IOException, EmbJoprTestException {
+ if( isJBossConfigWithoutCache() ) return;
- public void testHibernateSummary() throws HtmlElementNotFoundException {
- ejtt.navTree.getNodeByLabel(APP_TYPE.getNavTreeLabel());
- fail("JBoss Cache not present yet.");
+ NavTreeNode cachesNode = ejtt.navTree.getNodeByLabel(NAV_JBCACHES);
+ assertTrue( "JBoss Caches node has no children.", cachesNode.hasChildren() );
+ cachesNode.click();
+
+ final String HA_PARTITION = "ha-partition";
+ assertTrue("JBoss Caches should list '"+HA_PARTITION+"'", client.getPageAsText().contains(HA_PARTITION) );
+
+ ContentTable table = ejtt.getTabMenu().getTabContentBox().getFirstTable();
+
+ // Rows 1+
+ List<ContentTableRow> rows = table.getRows();
+ assertTrue( "Caches list should contain at least one cache.", rows.size() > 0 );
+
+ // Check that default cache is present.
+ boolean defaultPresent = false;
+ // Check that all caches are UP.
+ for( ContentTableRow row : rows ){
+ String name = row.getCellByColumnName(COL_RESOURCE_NAME).getTextContent();
+ String status = row.getCellByColumnName(COL_RESOURCE_STATUS).getTextContent().trim();
+ if( ! "UP".equals( status ) )
+ fail("Cache '"+name+"' is not UP, but '"+status+"'.");
+ if( DEFAULT_JBCACHE.equals(name) )
+ defaultPresent = true;
+ }
+ if( !defaultPresent)
+ fail("The default cache, '"+DEFAULT_JBCACHE+"', is not present.");
+
+ // Click on the first row link.
+ rows.get(0).getFirstLinkFromColumn(COL_RESOURCE_NAME).click();
+
+ // Check that we got to the Summary page.
+ assertTrue("JB Cache's Summary doesn't contain '"+LABEL_GENERAL_PROPERTIES+"' - is the Summary page ok?", client.getPageAsText().contains(LABEL_GENERAL_PROPERTIES));
+
}
+ /**
+ * JBoss Cache Summary tab.
+ */
+ public void testJBossCacheSummary() throws EmbJoprTestException, IOException {
+ if( isJBossConfigWithoutCache() ) return;
+
+ ejtt.navTree.getNodeByLabel(DEFAULT_JBCACHE).click();
+
+ /*
+ General Properties
+ Name:jboss.cache:config=ha-partition,service=Cache
+ Version:--
+ Description:JBoss Cache
+ */
+
+ /*ContentTable table = ejtt.getTabMenu().getTabContentBox().getTableUnderHeader(LABEL_GENERAL_PROPERTIES);
+ ContentInfoTable traitsTable = ejtt.getTabMenu().getTabContentBox().getContentInfoTable( table.getElement() );
+ Properties props = traitsTable.getProperties();
+
+ assertEquals("Traits - Name", DEFAULT_JBCACHE, props.getProperty("Name"));/**/
+
+ Properties props = new Properties();
+ props.setProperty("Name", DEFAULT_JBCACHE);
+ ejtt.getTabMenu().getTabContentBox().getTableUnformatted(LABEL_GENERAL_PROPERTIES).checkValues(props);
+
+
+
+ /*
+ Numeric Metrics
+ Name Value Description
+ Number of Nodes 1 Number of Nodes
+ */
+ props = new Properties();
+ props.setProperty("Number of Nodes", "1");
+ ejtt.getTabMenu().getTabContentBox().getTableUnderHeader(LABEL_NUMERIC_METRICS).checkValues(props);
+
+
+ }
+
+
- public void testHibernateMetrics() throws HtmlElementNotFoundException, IOException {
- fail("JBoss Cache not present yet.");
+ /**
+ * JBoss Cache Metrics tab.
+ */
+ public void testJBossCacheMetrics() throws HtmlElementNotFoundException, IOException, EmbJoprTestException {
+ if( isJBossConfigWithoutCache() ) return;
- ejtt.navTree.getNodeByLabel(APP_TYPE.getNavTreeLabel());
+ ejtt.navTree.getNodeByLabel(DEFAULT_JBCACHE).click();
ejtt.tabMenu.clickMetricsTab();
+ assertTrue( ejtt.tabMenu.isTabActive(TAB_NAME_METRICS) );
+ Properties props = new Properties();
+ props.setProperty("Node Locking Scheme:", "PESSIMISTIC");
+ props.setProperty("Expose Management Statistics?:", "true");
+ props.setProperty("Register JMX Resource?:", "true");
+ props.setProperty("Multiplexer Stack:", "udp");
+ props.setProperty("Cluster Name:", "DefaultPartition-HAPartitionCache");
+ props.setProperty("Inactive on Startup?:", "false");
+ props.setProperty("Cache Mode:", "REPL_SYNC");
+ props.setProperty("Isolation Level:", "REPEATABLE_READ");
+ props.setProperty("Replication Version:", "3.1.0");
+ props.setProperty("Fetch In-Memory State?:", "true");
+ props.setProperty("Use Replication Queue?:", "false");
+ props.setProperty("Use Region-Based Marshalling?:", "false");
+ props.setProperty("Sync Commit Phase?:", "false");
+ props.setProperty("State:", "3");
+ props.setProperty("Transaction Manager Lookup Class:", "org.jboss.cache.transaction.BatchModeTransactionManagerLookup");
+ ejtt.getTabMenu().getTabContentBox().getTableUnformatted(LABEL_TRAITS).checkValues(props);
+
+
+ // Numeric metrics
+ props = new Properties();
+ props.setProperty("Replication Queue Max Elements", "1,000");
+ props.setProperty("Number of Attributes", "0");
+ props.setProperty("Initial State Retrieval Timeout", "60,000");
+ props.setProperty("Replication Queue Interval", "5,000");
+ props.setProperty("Lock Acquisition Timeout", "15,000");
+ props.setProperty("Number of Nodes", "1");
+ props.setProperty("Sync Replication Timeout", "17,500");
+ props.setProperty("State Retrieval Timeout", "60,000");
+ ejtt.getTabMenu().getTabContentBox().getTableUnderHeader(LABEL_NUMERIC_METRICS).checkValues(props);
+
}
+
+ /**
+ * JBoss Cache Control tab.
+ */
+ public void testJBossCacheControl() throws HtmlElementNotFoundException, IOException {
+ if( isJBossConfigWithoutCache() ) return;
+
+ ejtt.navTree.getNodeByLabel(DEFAULT_JBCACHE).click();
+
+ ejtt.tabMenu.clickControlTab();
+ assertTrue( ejtt.tabMenu.isTabActive(TAB_NAME_CONTROL) );
+
+ }
+
}// class
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/EmbJoprTestToolkit.java
===================================================================
--- trunk/jsfunit/testdata/jbcache/JBossCacheTest-service.xml (rev 0)
+++ trunk/jsfunit/testdata/jbcache/JBossCacheTest-service.xml 2009-07-23 21:21:07 UTC (rev 580)
@@ -0,0 +1,20 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<server>
+<mbean code="org.jboss.cache.jmx.CacheJmxWrapper"
+name="foo:config=test,testName=testValue,Dname=testName,service=ExampleCacheJmxWrapper">
+<attribute name="TransactionManagerLookupClass">
+org.jboss.cache.transaction.JBossTransactionManagerLookup
+</attribute>
+<attribute name="MuxChannelFactory"><inject bean="JChannelFactory"/></attribute>
+<attribute name="MultiplexerStack">udp</attribute>
+<attribute name="ClusterName">Example-EntityCache</attribute>
+<attribute name="IsolationLevel">REPEATABLE_READ</attribute>
+<attribute name="CacheMode">REPL_SYNC</attribute>
+<attribute name="InitialStateRetrievalTimeout">15000</attribute>
+<attribute name="SyncReplTimeout">20000</attribute>
+<attribute name="LockAcquisitionTimeout">15000</attribute>
+<attribute name="ExposeManagementStatistics">true</attribute>
+</mbean>
+
+</server>
+
15 years, 5 months
EMBJOPR SVN: r579 - trunk.
by embjopr-commits@lists.jboss.org
Author: asafs
Date: 2009-07-23 14:24:30 -0400 (Thu, 23 Jul 2009)
New Revision: 579
Modified:
trunk/.classpath
Log:
Updated libraries dependencies in Eclipse .classpath
Modified: trunk/.classpath
===================================================================
--- trunk/.classpath 2009-07-23 18:17:22 UTC (rev 578)
+++ trunk/.classpath 2009-07-23 18:24:30 UTC (rev 579)
@@ -26,11 +26,11 @@
<classpathentry kind="var" path="M2_REPO/org/jboss/microcontainer/jboss-deployers-client-spi/2.0.0.Beta6/jboss-deployers-client-spi-2.0.0.Beta6.jar" sourcepath="M2_REPO/org/jboss/microcontainer/jboss-deployers-client-spi/2.0.0.Beta6/jboss-deployers-client-spi-2.0.0.Beta6-sources.jar"/>
<classpathentry kind="var" path="M2_REPO/org/jboss/microcontainer/jboss-deployers-core-spi/2.0.0.Beta6/jboss-deployers-core-spi-2.0.0.Beta6.jar" sourcepath="M2_REPO/org/jboss/microcontainer/jboss-deployers-core-spi/2.0.0.Beta6/jboss-deployers-core-spi-2.0.0.Beta6-sources.jar"/>
<classpathentry kind="var" path="M2_REPO/org/jboss/el/jboss-el/2.0.1.GA/jboss-el-2.0.1.GA.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/jboss/seam/embedded/jboss-embedded-all/beta3.SP2/jboss-embedded-all-beta3.SP2.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/jboss/seam/embedded/jboss-embedded-api/beta3.SP2/jboss-embedded-api-beta3.SP2.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/jboss/seam/jboss-seam/2.0.2.SP1/jboss-seam-2.0.2.SP1.jar" sourcepath="M2_REPO/org/jboss/seam/jboss-seam/2.0.2.SP1/jboss-seam-2.0.2.SP1-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/jboss/seam/jboss-seam-debug/2.0.2.SP1/jboss-seam-debug-2.0.2.SP1.jar" sourcepath="M2_REPO/org/jboss/seam/jboss-seam-debug/2.0.2.SP1/jboss-seam-debug-2.0.2.SP1-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/jboss/seam/jboss-seam-ui/2.0.2.SP1/jboss-seam-ui-2.0.2.SP1.jar" sourcepath="M2_REPO/org/jboss/seam/jboss-seam-ui/2.0.2.SP1/jboss-seam-ui-2.0.2.SP1-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/jboss/seam/embedded/jboss-embedded-all/beta3.SP3/jboss-embedded-all-beta3.SP3.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/jboss/seam/embedded/jboss-embedded-api/beta3.SP3/jboss-embedded-api-beta3.SP3.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/jboss/seam/jboss-seam/2.1.0.SP1/jboss-seam-2.1.0.SP1.jar" sourcepath="M2_REPO/org/jboss/seam/jboss-seam/2.0.2.SP1/jboss-seam-2.0.2.SP1-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/jboss/seam/jboss-seam-debug/2.1.0.SP1/jboss-seam-debug-2.1.0.SP1.jar" sourcepath="M2_REPO/org/jboss/seam/jboss-seam-debug/2.0.2.SP1/jboss-seam-debug-2.0.2.SP1-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/jboss/seam/jboss-seam-ui/2.1.0.SP1/jboss-seam-ui-2.1.0.SP1.jar" sourcepath="M2_REPO/org/jboss/seam/jboss-seam-ui/2.0.2.SP1/jboss-seam-ui-2.0.2.SP1-sources.jar"/>
<classpathentry kind="var" path="M2_REPO/jdom/jdom/1.0/jdom-1.0.jar" sourcepath="M2_REPO/jdom/jdom/1.0/jdom-1.0-sources.jar"/>
<classpathentry kind="var" path="M2_REPO/javax/faces/jsf-api/1.2_10/jsf-api-1.2_10.jar"/>
<classpathentry kind="var" path="M2_REPO/com/sun/facelets/jsf-facelets/1.1.15.B1/jsf-facelets-1.1.15.B1.jar" sourcepath="M2_REPO/com/sun/facelets/jsf-facelets/1.1.15.B1/jsf-facelets-1.1.15.B1-sources.jar"/>
@@ -39,20 +39,20 @@
<classpathentry kind="var" path="M2_REPO/junit/junit/3.8.1/junit-3.8.1.jar" sourcepath="M2_REPO/junit/junit/3.8.1/junit-3.8.1-sources.jar"/>
<classpathentry kind="var" path="M2_REPO/log4j/log4j/1.2.14/log4j-1.2.14.jar" sourcepath="M2_REPO/log4j/log4j/1.2.14/log4j-1.2.14-sources.jar"/>
<classpathentry kind="var" path="M2_REPO/javax/persistence/persistence-api/1.0/persistence-api-1.0.jar" sourcepath="M2_REPO/javax/persistence/persistence-api/1.0/persistence-api-1.0-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-client-api/1.2.0-SNAPSHOT/rhq-core-client-api-1.2.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-client-api/1.2.0-SNAPSHOT/rhq-core-client-api-1.2.0-SNAPSHOT-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-comm-api/1.2.0-SNAPSHOT/rhq-core-comm-api-1.2.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-comm-api/1.2.0-SNAPSHOT/rhq-core-comm-api-1.2.0-SNAPSHOT-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-domain/1.2.0-SNAPSHOT/rhq-core-domain-1.2.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-domain/1.2.0-SNAPSHOT/rhq-core-domain-1.2.0-SNAPSHOT-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-gui/1.2.0-SNAPSHOT/rhq-core-gui-1.2.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-gui/1.2.0-SNAPSHOT/rhq-core-gui-1.2.0-SNAPSHOT-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-native-system/1.2.0-SNAPSHOT/rhq-core-native-system-1.2.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-native-system/1.2.0-SNAPSHOT/rhq-core-native-system-1.2.0-SNAPSHOT-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-plugin-api/1.2.0-SNAPSHOT/rhq-core-plugin-api-1.2.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-plugin-api/1.2.0-SNAPSHOT/rhq-core-plugin-api-1.2.0-SNAPSHOT-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-plugin-container/1.2.0-SNAPSHOT/rhq-core-plugin-container-1.2.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-plugin-container/1.2.0-SNAPSHOT/rhq-core-plugin-container-1.2.0-SNAPSHOT-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-util/1.2.0-SNAPSHOT/rhq-core-util-1.2.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-util/1.2.0-SNAPSHOT/rhq-core-util-1.2.0-SNAPSHOT-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/richfaces/framework/richfaces-api/3.2.2.GA/richfaces-api-3.2.2.GA.jar" sourcepath="M2_REPO/org/richfaces/framework/richfaces-api/3.2.2.GA/richfaces-api-3.2.2.GA-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/richfaces/framework/richfaces-impl/3.2.2.GA/richfaces-impl-3.2.2.GA.jar" sourcepath="M2_REPO/org/richfaces/framework/richfaces-impl/3.2.2.GA/richfaces-impl-3.2.2.GA-sources.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/richfaces/ui/richfaces-ui/3.2.2.GA/richfaces-ui-3.2.2.GA.jar" sourcepath="M2_REPO/org/richfaces/ui/richfaces-ui/3.2.2.GA/richfaces-ui-3.2.2.GA-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-client-api/1.3.0-SNAPSHOT/rhq-core-client-api-1.3.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-client-api/1.2.0-SNAPSHOT/rhq-core-client-api-1.2.0-SNAPSHOT-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-comm-api/1.3.0-SNAPSHOT/rhq-core-comm-api-1.3.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-comm-api/1.2.0-SNAPSHOT/rhq-core-comm-api-1.2.0-SNAPSHOT-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-domain/1.3.0-SNAPSHOT/rhq-core-domain-1.3.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-domain/1.2.0-SNAPSHOT/rhq-core-domain-1.2.0-SNAPSHOT-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-gui/1.3.0-SNAPSHOT/rhq-core-gui-1.3.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-gui/1.2.0-SNAPSHOT/rhq-core-gui-1.2.0-SNAPSHOT-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-native-system/1.3.0-SNAPSHOT/rhq-core-native-system-1.3.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-native-system/1.2.0-SNAPSHOT/rhq-core-native-system-1.2.0-SNAPSHOT-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-plugin-api/1.3.0-SNAPSHOT/rhq-core-plugin-api-1.3.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-plugin-api/1.2.0-SNAPSHOT/rhq-core-plugin-api-1.2.0-SNAPSHOT-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-plugin-container/1.3.0-SNAPSHOT/rhq-core-plugin-container-1.3.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-plugin-container/1.2.0-SNAPSHOT/rhq-core-plugin-container-1.2.0-SNAPSHOT-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/rhq/rhq-core-util/1.3.0-SNAPSHOT/rhq-core-util-1.3.0-SNAPSHOT.jar" sourcepath="M2_REPO/org/rhq/rhq-core-util/1.2.0-SNAPSHOT/rhq-core-util-1.2.0-SNAPSHOT-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/richfaces/framework/richfaces-api/3.3.0.GA/richfaces-api-3.3.0.GA.jar" sourcepath="M2_REPO/org/richfaces/framework/richfaces-api/3.2.2.GA/richfaces-api-3.2.2.GA-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/richfaces/framework/richfaces-impl/3.3.0.GA/richfaces-impl-3.3.0.GA.jar" sourcepath="M2_REPO/org/richfaces/framework/richfaces-impl/3.2.2.GA/richfaces-impl-3.2.2.GA-sources.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/richfaces/ui/richfaces-ui/3.3.0.GA/richfaces-ui-3.3.0.GA.jar" sourcepath="M2_REPO/org/richfaces/ui/richfaces-ui/3.2.2.GA/richfaces-ui-3.2.2.GA-sources.jar"/>
<classpathentry kind="var" path="M2_REPO/javax/servlet/servlet-api/2.4/servlet-api-2.4.jar" sourcepath="M2_REPO/javax/servlet/servlet-api/2.4/servlet-api-2.4-sources.jar"/>
<classpathentry kind="var" path="M2_REPO/javax/xml/stream/stax-api/1.0-2/stax-api-1.0-2.jar" sourcepath="M2_REPO/javax/xml/stream/stax-api/1.0-2/stax-api-1.0-2-sources.jar"/>
<classpathentry kind="var" path="M2_REPO/org/testng/testng/5.7/testng-5.7-jdk15.jar"/>
- <classpathentry kind="var" path="M2_REPO/org/jboss/seam/embedded/thirdparty-all/beta3.SP2/thirdparty-all-beta3.SP2.jar"/>
+ <classpathentry kind="var" path="M2_REPO/org/jboss/seam/embedded/thirdparty-all/beta3.SP3/thirdparty-all-beta3.SP3.jar"/>
<classpathentry kind="output" path="eclipse-classes"/>
</classpath>
15 years, 5 months
EMBJOPR SVN: r577 - in trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit: as4 and 5 other directories.
by embjopr-commits@lists.jboss.org
Author: ozizka(a)redhat.com
Date: 2009-07-22 20:15:52 -0400 (Wed, 22 Jul 2009)
New Revision: 577
Added:
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/ProfileServiceUtils.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/jaas/SecuredProfileServiceAccess.java
Removed:
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/jaas/JaasUtils.java
Modified:
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/AppConstants.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbjoprTestCase.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as4/DatasourceTest.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/hbn/HibernateTest.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/jbcache/JBossCacheTest.java
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/EmbJoprTestToolkit.java
Log:
* ProfileService access refactored.
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/AppConstants.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/AppConstants.java 2009-07-22 19:24:37 UTC (rev 576)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/AppConstants.java 2009-07-23 00:15:52 UTC (rev 577)
@@ -55,7 +55,7 @@
EMB_WAR(AppConstants.NAV_EMB_WAR,"Embbedded WAR", "", ".war", null, "application/war"),
// TODO: Create a superclass for non-app resource types - ResourceTypes.
- JBCACHE(AppConstants.NAV_JBCACHE, "JBoss Cache", null, null, null, null),
+ JBCACHE(AppConstants.NAV_JBCACHE, "Jboss Cache", null, null, null, null), // TODO: Should be JBoss
HBN(AppConstants.NAV_HBN, "Hibernate", null, null, null, null);
@@ -147,6 +147,7 @@
public static final String NAV_SBMS = "Service Binding Managers";
public static final String NAV_SBM = "ServiceBindingManager";
public static final String NAV_JBCACHE = "JBoss Cache";
+ public static final String NAV_JBCACHES = "Jboss Caches";
public static final String NAV_HBN = "Hibernate";
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbjoprTestCase.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbjoprTestCase.java 2009-07-22 19:24:37 UTC (rev 576)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbjoprTestCase.java 2009-07-23 00:15:52 UTC (rev 577)
@@ -48,7 +48,7 @@
import org.jboss.jopr.jsfunit.exceptions.EmbJoprTestException;
import org.jboss.jopr.jsfunit.exceptions.HtmlElementNotFoundException;
import org.jboss.jopr.jsfunit.util.EmbJoprTestToolkit;
-import org.jboss.jopr.jsfunit.util.jaas.JaasUtils;
+import org.jboss.jopr.jsfunit.util.jaas.SecuredProfileServiceAccess;
/**
@@ -95,7 +95,7 @@
* created each time a test is run.
*/
@Override
- public void setUp() throws IOException
+ public void setUp() throws IOException, EmbJoprTestException
{
// Announce this test in the JBoss log.
@@ -982,9 +982,13 @@
*/
protected ManagedComponent getManagedComponent(String componentName,
ComponentType type) throws Exception {
- return getManagedComponent(componentName, type, false);
+ return getManagedComponent(componentName, type, true);
}
+ /**
+ * Return a ManagedComponent, given the component name and type.
+ * @param secured If true, uses JAAS secured access to ProfileService etc.
+ */
protected ManagedComponent getManagedComponent(String componentName,
ComponentType type, boolean secured) throws Exception {
@@ -1032,7 +1036,7 @@
protected ProfileService getProfileServiceSecured()
{
try {
- return JaasUtils.getInstance().getProfileService();
+ return SecuredProfileServiceAccess.getInstance().getProfileService();
} catch (NamingException ex) {
// Farah's methods don't propagate exceptions -> report and swallow.
log.error("Can't get secured ProfileService: " + ex.toString(), ex);
@@ -1067,14 +1071,16 @@
* Get the current profile view.
* @param secured If true, returns JAAS profile view of secured profile service.
*/
- protected ManagementView getCurrentProfileView( boolean secured ){ return secured ? getCurrentProfileViewSecured() : getCurrentProfileView(); }
+ protected ManagementView getCurrentProfileView( boolean secured ){
+ return secured ? getCurrentProfileView() : getCurrentProfileViewUnsecured();
+ }
/**
* Get the current profile view.
*/
- protected ManagementView getCurrentProfileViewSecured(){
+ protected ManagementView getCurrentProfileView(){
try {
- ManagementView view = JaasUtils.getInstance().getManagementView();
+ ManagementView view = SecuredProfileServiceAccess.getInstance().getManagementView();
view.load();
return view;
} catch (NamingException ex) {
@@ -1083,7 +1089,7 @@
}
}
- protected ManagementView getCurrentProfileView()
+ protected ManagementView getCurrentProfileViewUnsecured()
{
ProfileService profileService = getProfileService();
ManagementView currentProfileView = profileService.getViewManager();
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as4/DatasourceTest.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as4/DatasourceTest.java 2009-07-22 19:24:37 UTC (rev 576)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as4/DatasourceTest.java 2009-07-23 00:15:52 UTC (rev 577)
@@ -47,13 +47,6 @@
public class DatasourceTest extends org.jboss.jopr.jsfunit.DatasourceTestBase {
- @Override
- public void setUp() throws IOException {
- super.setUp();
- }
-
-
-
/**
* Create a new datasource using the given template and properties.
*
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java 2009-07-22 19:24:37 UTC (rev 576)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java 2009-07-23 00:15:52 UTC (rev 577)
@@ -29,11 +29,13 @@
import javax.naming.InitialContext;
import javax.naming.NamingException;
+import junit.framework.Test;
+import junit.framework.TestSuite;
import org.jboss.deployers.spi.management.ManagementView;
import org.jboss.deployers.spi.management.deploy.DeploymentManager;
import org.jboss.deployers.spi.management.deploy.DeploymentProgress;
import org.jboss.jopr.jsfunit.EmbjoprTestCase;
-import org.jboss.jopr.jsfunit.util.jaas.JaasUtils;
+import org.jboss.jopr.jsfunit.util.jaas.SecuredProfileServiceAccess;
import org.jboss.managed.api.ComponentType;
import org.jboss.managed.api.DeploymentTemplateInfo;
import org.jboss.managed.api.ManagedComponent;
@@ -41,8 +43,6 @@
import org.jboss.metatype.api.values.MetaValue;
import org.jboss.metatype.api.values.MetaValueFactory;
import org.jboss.profileservice.spi.ProfileKey;
-import org.jboss.profileservice.spi.ProfileService;
-import org.jboss.virtual.VFS;
@@ -60,7 +60,8 @@
protected DeploymentManager deployMgr;
private MetaValueFactory metaValueFactory;
- public ProfileServiceTest(String name){
+
+ public ProfileServiceTest(String name){
super();
}
public ProfileServiceTest(){
@@ -68,11 +69,19 @@
}
+ public static Test suite(){
+ return new TestSuite(EarStressTest.class);
+ }
+
+
+
+
+
/**
* List the contents of ProfileService.
*/
public void testProfileServiceListContent() throws NamingException, Exception{
- ManagementView managementView = JaasUtils.getInstance().getManagementView();
+ ManagementView managementView = SecuredProfileServiceAccess.getInstance().getManagementView();
log.info("List of ProfileService contents (default profile):");
@@ -222,7 +231,7 @@
return activeView;
/**/
- return JaasUtils.getInstance().getManagementView();
+ return SecuredProfileServiceAccess.getInstance().getManagementView();
}
/**
* Obtain the ProfileService.ManagementView
@@ -244,7 +253,7 @@
}
return deployMgr;
/**/
- return JaasUtils.getInstance().getDeploymentManager();
+ return SecuredProfileServiceAccess.getInstance().getDeploymentManager();
}
/**
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/hbn/HibernateTest.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/hbn/HibernateTest.java 2009-07-22 19:24:37 UTC (rev 576)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/hbn/HibernateTest.java 2009-07-23 00:15:52 UTC (rev 577)
@@ -17,6 +17,14 @@
+ public void testHibernateParentNode() throws HtmlElementNotFoundException {
+ fail("Hibernate not present yet.");
+
+ ejtt.navTree.getNodeByLabel(APP_TYPE.getNavTreeLabel());
+ }
+
+
+
public void testHibernateSummary() throws HtmlElementNotFoundException {
fail("Hibernate not present yet.");
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/jbcache/JBossCacheTest.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/jbcache/JBossCacheTest.java 2009-07-22 19:24:37 UTC (rev 576)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/jbcache/JBossCacheTest.java 2009-07-23 00:15:52 UTC (rev 577)
@@ -17,10 +17,15 @@
- public void testHibernateSummary() throws HtmlElementNotFoundException {
+ public void testJBossCacheParentNode() throws HtmlElementNotFoundException {
+ ejtt.navTree.getNodeByLabel(APP_TYPE.getNavTreeLabel());
fail("JBoss Cache not present yet.");
+ }
+
+ public void testHibernateSummary() throws HtmlElementNotFoundException {
ejtt.navTree.getNodeByLabel(APP_TYPE.getNavTreeLabel());
+ fail("JBoss Cache not present yet.");
}
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/EmbJoprTestToolkit.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/EmbJoprTestToolkit.java 2009-07-22 19:24:37 UTC (rev 576)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/EmbJoprTestToolkit.java 2009-07-23 00:15:52 UTC (rev 577)
@@ -9,6 +9,7 @@
import java.util.logging.Level;
import javax.management.MalformedObjectNameException;
+import javax.naming.NamingException;
import org.jboss.jopr.jsfunit.exceptions.*;
import com.gargoylesoftware.htmlunit.html.*;
import com.gargoylesoftware.htmlunit.javascript.JavaScriptEngine;
@@ -60,19 +61,34 @@
public JSFServerSession getServer() { return server; }
- public EmbJoprTestToolkit(JSFClientSession client, JSFServerSession server) {
+ public EmbJoprTestToolkit(JSFClientSession client, JSFServerSession server) throws EmbJoprTestException {
this.client = client;
this.server = server;
this.selfEjtt = this;
+
+ try {
+ profileService = new ProfileServiceUtils(true); // TODO: Make "secured" configurable in POM.
+ } catch (NamingException ex) {
+ String message = "Error when initializing ProfileService: "+ex;
+ log.fatal( message );
+ throw new EmbJoprTestException(message, ex);
+ }
}
+
+ /** Used in inner classes (they can't use this). */
public EmbJoprTestToolkit getEjtt(){ return this; }
- private EmbjoprTestCase currentTest = null;
+ /** Returns information about current test being run. Filled before each test method (in setUp()). */
public EmbjoprTestCase getCurrentTest() { return currentTest; }
public void setCurrentTest(EmbjoprTestCase currentTest) { this.currentTest = currentTest; }
+ private EmbjoprTestCase currentTest = null;
+ /**
+ * ProfileService references.
+ */
+ public final ProfileServiceUtils profileService;
/**
@@ -2183,38 +2199,4 @@
-
- // TODO
- protected class JMXDeploymentInfo {
-
- // Etc...
- public boolean isDeployed(){
- return false;
- }
-
- }
-
- // TODO
- protected class FileDeploymentInfo {
-
- // Etc...
- public boolean isDeployed(){
- return false;
- }
-
- }
-
- // TODO
- protected class EmbJoprDeploymentInfo {
-
- // Etc...
- public boolean isDeployed(){
- return false;
- }
-
- }
-
-
-
-
}// class EmbJoprTestToolkit
Added: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/ProfileServiceUtils.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/ProfileServiceUtils.java (rev 0)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/ProfileServiceUtils.java 2009-07-23 00:15:52 UTC (rev 577)
@@ -0,0 +1,49 @@
+package org.jboss.jopr.jsfunit.util;
+
+import javax.naming.NamingException;
+import org.jboss.deployers.spi.management.ManagementView;
+import org.jboss.deployers.spi.management.deploy.DeploymentManager;
+import org.jboss.jopr.jsfunit.util.jaas.SecuredProfileServiceAccess;
+import org.jboss.profileservice.spi.ProfileService;
+
+
+/**
+ * Immutable class holding references to ProfileService, ManagementView and DeploymentManager,
+ * either secured or unsecured, depending on constructor parameter.
+ * @author Ondrej Zizka
+ */
+public class ProfileServiceUtils {
+
+ // Properties
+ final ProfileService profileService;
+ final ManagementView managementView;
+ final DeploymentManager deploymentManager;
+ final boolean secured;
+
+ public DeploymentManager getDeploymentManager() { return deploymentManager; }
+ public ManagementView getManagementView() { return managementView; }
+ public ProfileService getProfileService() { return profileService; }
+ public boolean isSecured() { return secured; }
+
+
+
+ // Ctor.
+
+ public ProfileServiceUtils( boolean secured ) throws NamingException
+ {
+ this.secured = secured;
+
+ SecuredProfileServiceAccess jaasUtils = null;
+
+ jaasUtils = secured ? SecuredProfileServiceAccess.getSecuredInstance() : SecuredProfileServiceAccess.getUnsecuredInstance();
+
+ // NPE will occur here if exception happens above.
+ // TODO: Move ejtt's members initialization to some init() method to avoid this nasty thing.
+ this.profileService = jaasUtils.getProfileService();
+ this.managementView = jaasUtils.getManagementView();
+ this.deploymentManager = jaasUtils.getDeploymentManager();
+ }
+
+
+}
+// class ProfileServiceUtils
Deleted: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/jaas/JaasUtils.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/jaas/JaasUtils.java 2009-07-22 19:24:37 UTC (rev 576)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/jaas/JaasUtils.java 2009-07-23 00:15:52 UTC (rev 577)
@@ -1,114 +0,0 @@
-package org.jboss.jopr.jsfunit.util.jaas;
-
-import java.lang.reflect.Proxy;
-
-import java.util.Properties;
-
-import javax.naming.Context;
-import javax.naming.InitialContext;
-import javax.naming.NamingException;
-
-import org.jboss.deployers.spi.management.ManagementView;
-import org.jboss.deployers.spi.management.deploy.DeploymentManager;
-import org.jboss.logging.Logger;
-import org.jboss.profileservice.spi.ProfileService;
-
-
-
-/**
- * Singleton class to keep JAAS secured ProfileService, ManagementView and DeploymentManager.
- * Partially copied from Jopr's test.EjbClient.
- * @author Ondrej Zizka
- */
-public class JaasUtils {
-
- private static final Logger log = Logger.getLogger(JaasUtils.class);
-
- // Singleton.
- private static JaasUtils INSTANCE = null;
- public static JaasUtils getInstance() throws NamingException {
- if( null == INSTANCE ){
- INSTANCE = new JaasUtils();
- INSTANCE.init( true );
- }
- return INSTANCE;
- }
-
- private static final String JNDI_LOGIN_INITIAL_CONTEXT_FACTORY = "org.jboss.security.jndi.JndiLoginInitialContextFactory";
- private static final String NAMING_CONTEXT_FACTORY = "org.jnp.interfaces.NamingContextFactory";
- private static final String SECURE_PROFILE_SERVICE_JNDI_NAME = "SecureProfileService/remote";
- private static final String SECURE_MANAGEMENT_VIEW_JNDI_NAME = "SecureManagementView/remote";
- private static final String SECURE_DEPLOYMENT_MANAGER_JNDI_NAME = "SecureDeploymentManager/remote";
- private static final String PROFILE_SERVICE_JNDI_NAME = "ProfileService";
- private static final String MANAGEMENT_VIEW_JNDI_NAME = "ManagementView";
- private static final String DEPLOYMENT_MANAGER_JNDI_NAME = "DeploymentManager";
- private static final String PROFILE_SERVICE_PRINCIPAL = "admin";
- private static final String PROFILE_SERVICE_CREDENTIALS = "admin";
-
-
- ProfileService profileService;
- ManagementView managementView;
- DeploymentManager deploymentManager;
-
- public DeploymentManager getDeploymentManager() { return deploymentManager; }
- public ManagementView getManagementView() { return managementView; }
- public ProfileService getProfileService() { return profileService; }
-
-
- /**
- * Obtains ProfileService, ManagementView and DeploymentManager.
- * @param useJaas If true, all those three are secured with JAAS.
- */
- private void init(boolean useJaas) throws NamingException {
-
- Properties env = new Properties();
- env.setProperty(Context.PROVIDER_URL, "jnp://127.0.0.1:1099/");
- env.setProperty(Context.INITIAL_CONTEXT_FACTORY, NAMING_CONTEXT_FACTORY);
-
- InitialContext initialContext = createInitialContext(env);
-
-
- if (!useJaas) {
- this.profileService = (ProfileService) lookup(initialContext, PROFILE_SERVICE_JNDI_NAME);
- this.managementView = this.profileService.getViewManager();
- this.deploymentManager = this.profileService.getDeploymentManager();
- }
- else {
- this.profileService = (ProfileService) lookup(initialContext, PROFILE_SERVICE_JNDI_NAME);
- this.managementView = (ManagementView) lookup(initialContext, MANAGEMENT_VIEW_JNDI_NAME);
- this.deploymentManager = (DeploymentManager) lookup(initialContext, DEPLOYMENT_MANAGER_JNDI_NAME);
-
- //apply the jaas security
- ClassLoader classLoader = JaasUtils.class.getClassLoader();
- this.profileService = (ProfileService) Proxy.newProxyInstance(classLoader,
- new Class<?>[]{ProfileService.class},
- new JaasAuthenticationInvocationHandler( this.profileService, PROFILE_SERVICE_PRINCIPAL, PROFILE_SERVICE_CREDENTIALS ));
-
- this.managementView = (ManagementView) Proxy.newProxyInstance(classLoader,
- new Class<?>[]{ManagementView.class},
- new JaasAuthenticationInvocationHandler( this.managementView, PROFILE_SERVICE_PRINCIPAL, PROFILE_SERVICE_CREDENTIALS ));
-
- this.deploymentManager = (DeploymentManager) Proxy.newProxyInstance(classLoader,
- new Class<?>[]{DeploymentManager.class},
- new JaasAuthenticationInvocationHandler( this.deploymentManager, PROFILE_SERVICE_PRINCIPAL, PROFILE_SERVICE_CREDENTIALS ));
- }
-
- // This must be called before the other ManagementView operations may be used.
- this.managementView.load();
- }
-
-
- private static InitialContext createInitialContext(Properties env) throws NamingException {
- log.info("Creating JNDI InitialContext with env [" + env + "]...");
- InitialContext initialContext = new InitialContext(env);
- log.info("Created JNDI InitialContext [" + initialContext + "].");
- return initialContext;
- }
-
- private static Object lookup(InitialContext initialContext, String name) throws NamingException {
- log.info("Looking up name '" + name + "' from InitialContext...");
- Object obj = initialContext.lookup(name);
- log.info("Found Object: " + obj);
- return obj;
- }
-}// class
Copied: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/jaas/SecuredProfileServiceAccess.java (from rev 568, trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/jaas/JaasUtils.java)
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/jaas/SecuredProfileServiceAccess.java (rev 0)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/jaas/SecuredProfileServiceAccess.java 2009-07-23 00:15:52 UTC (rev 577)
@@ -0,0 +1,127 @@
+package org.jboss.jopr.jsfunit.util.jaas;
+
+import java.lang.reflect.Proxy;
+
+import java.util.Properties;
+
+import javax.naming.Context;
+import javax.naming.InitialContext;
+import javax.naming.NamingException;
+
+import org.jboss.deployers.spi.management.ManagementView;
+import org.jboss.deployers.spi.management.deploy.DeploymentManager;
+import org.jboss.logging.Logger;
+import org.jboss.profileservice.spi.ProfileService;
+
+
+
+/**
+ * Singleton class to keep JAAS secured ProfileService, ManagementView and DeploymentManager.
+ * Partially copied from Jopr's test.EjbClient.
+ * @author Ondrej Zizka
+ *
+ */
+public class SecuredProfileServiceAccess {
+
+ private static final Logger log = Logger.getLogger(SecuredProfileServiceAccess.class);
+
+ // Singleton.
+ private static SecuredProfileServiceAccess INSTANCE_SECURED = null;
+ private static SecuredProfileServiceAccess INSTANCE_UNSECURED = null;
+
+ public static SecuredProfileServiceAccess getInstance() throws NamingException { return getSecuredInstance(); }
+
+ public static SecuredProfileServiceAccess getSecuredInstance() throws NamingException {
+ if( null == INSTANCE_SECURED ){
+ INSTANCE_SECURED = new SecuredProfileServiceAccess();
+ INSTANCE_SECURED.init( true );
+ }
+ return INSTANCE_SECURED;
+ }
+
+ public static SecuredProfileServiceAccess getUnsecuredInstance() throws NamingException {
+ if( null == INSTANCE_UNSECURED ){
+ INSTANCE_UNSECURED = new SecuredProfileServiceAccess();
+ INSTANCE_UNSECURED.init( false );
+ }
+ return INSTANCE_UNSECURED;
+ }
+
+ private static final String JNDI_LOGIN_INITIAL_CONTEXT_FACTORY = "org.jboss.security.jndi.JndiLoginInitialContextFactory";
+ private static final String NAMING_CONTEXT_FACTORY = "org.jnp.interfaces.NamingContextFactory";
+ private static final String SECURE_PROFILE_SERVICE_JNDI_NAME = "SecureProfileService/remote";
+ private static final String SECURE_MANAGEMENT_VIEW_JNDI_NAME = "SecureManagementView/remote";
+ private static final String SECURE_DEPLOYMENT_MANAGER_JNDI_NAME = "SecureDeploymentManager/remote";
+ private static final String PROFILE_SERVICE_JNDI_NAME = "ProfileService";
+ private static final String MANAGEMENT_VIEW_JNDI_NAME = "ManagementView";
+ private static final String DEPLOYMENT_MANAGER_JNDI_NAME = "DeploymentManager";
+ private static final String PROFILE_SERVICE_PRINCIPAL = "admin";
+ private static final String PROFILE_SERVICE_CREDENTIALS = "admin";
+
+
+ ProfileService profileService;
+ ManagementView managementView;
+ DeploymentManager deploymentManager;
+
+ public DeploymentManager getDeploymentManager() { return deploymentManager; }
+ public ManagementView getManagementView() { return managementView; }
+ public ProfileService getProfileService() { return profileService; }
+
+
+ /**
+ * Obtains ProfileService, ManagementView and DeploymentManager.
+ * @param useJaas If true, all those three are secured with JAAS.
+ */
+ private void init(boolean useJaas) throws NamingException {
+
+ Properties env = new Properties();
+ env.setProperty(Context.PROVIDER_URL, "jnp://127.0.0.1:1099/");
+ env.setProperty(Context.INITIAL_CONTEXT_FACTORY, NAMING_CONTEXT_FACTORY);
+
+ InitialContext initialContext = createInitialContext(env);
+
+
+ if (!useJaas) {
+ this.profileService = (ProfileService) lookup(initialContext, PROFILE_SERVICE_JNDI_NAME);
+ this.managementView = this.profileService.getViewManager();
+ this.deploymentManager = this.profileService.getDeploymentManager();
+ }
+ else {
+ this.profileService = (ProfileService) lookup(initialContext, PROFILE_SERVICE_JNDI_NAME);
+ this.managementView = (ManagementView) lookup(initialContext, MANAGEMENT_VIEW_JNDI_NAME);
+ this.deploymentManager = (DeploymentManager) lookup(initialContext, DEPLOYMENT_MANAGER_JNDI_NAME);
+
+ //apply the jaas security
+ ClassLoader classLoader = SecuredProfileServiceAccess.class.getClassLoader();
+ this.profileService = (ProfileService) Proxy.newProxyInstance(classLoader,
+ new Class<?>[]{ProfileService.class},
+ new JaasAuthenticationInvocationHandler( this.profileService, PROFILE_SERVICE_PRINCIPAL, PROFILE_SERVICE_CREDENTIALS ));
+
+ this.managementView = (ManagementView) Proxy.newProxyInstance(classLoader,
+ new Class<?>[]{ManagementView.class},
+ new JaasAuthenticationInvocationHandler( this.managementView, PROFILE_SERVICE_PRINCIPAL, PROFILE_SERVICE_CREDENTIALS ));
+
+ this.deploymentManager = (DeploymentManager) Proxy.newProxyInstance(classLoader,
+ new Class<?>[]{DeploymentManager.class},
+ new JaasAuthenticationInvocationHandler( this.deploymentManager, PROFILE_SERVICE_PRINCIPAL, PROFILE_SERVICE_CREDENTIALS ));
+ }
+
+ // This must be called before the other ManagementView operations may be used.
+ this.managementView.load();
+ }
+
+
+ private static InitialContext createInitialContext(Properties env) throws NamingException {
+ log.info("Creating JNDI InitialContext with env [" + env + "]...");
+ InitialContext initialContext = new InitialContext(env);
+ log.info("Created JNDI InitialContext [" + initialContext + "].");
+ return initialContext;
+ }
+
+ private static Object lookup(InitialContext initialContext, String name) throws NamingException {
+ log.info("Looking up name '" + name + "' from InitialContext...");
+ Object obj = initialContext.lookup(name);
+ log.info("Found Object: " + obj);
+ return obj;
+ }
+}// class
15 years, 5 months
EMBJOPR SVN: r576 - trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear.
by embjopr-commits@lists.jboss.org
Author: ozizka(a)redhat.com
Date: 2009-07-22 15:24:37 -0400 (Wed, 22 Jul 2009)
New Revision: 576
Modified:
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/RepeatedDeploymentViaPSTest.java
Log:
* ProfileServiceTest test listing now uses current PS spi. (2)
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/RepeatedDeploymentViaPSTest.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/RepeatedDeploymentViaPSTest.java 2009-07-22 19:23:36 UTC (rev 575)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/RepeatedDeploymentViaPSTest.java 2009-07-22 19:24:37 UTC (rev 576)
@@ -24,7 +24,7 @@
* Mostly copied from
* jboss-as-5.x/testsuite/src/main/org/jboss/test/profileservice/test
*/
-public class RepeatedDeploymentViaPSTest extends AbstractProfileServiceTest implements ProgressListener {
+public class RepeatedDeploymentViaPSTest extends ProfileServiceTest implements ProgressListener {
15 years, 5 months
EMBJOPR SVN: r575 - trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear.
by embjopr-commits@lists.jboss.org
Author: ozizka(a)redhat.com
Date: 2009-07-22 15:23:36 -0400 (Wed, 22 Jul 2009)
New Revision: 575
Added:
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java
Removed:
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/AbstractProfileServiceTest.java
Log:
* ProfileServiceTest test listing now uses current PS spi.
Deleted: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/AbstractProfileServiceTest.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/AbstractProfileServiceTest.java 2009-07-22 16:20:31 UTC (rev 574)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/AbstractProfileServiceTest.java 2009-07-22 19:23:36 UTC (rev 575)
@@ -1,256 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source.
- * Copyright 2008, Red Hat Middleware LLC, and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.jopr.jsfunit.as5.app.ear;
-
-import java.util.Collections;
-import java.util.HashSet;
-import java.util.Map;
-import java.util.Set;
-
-import javax.naming.InitialContext;
-
-import javax.naming.NamingException;
-import org.jboss.deployers.spi.management.ManagementView;
-import org.jboss.deployers.spi.management.deploy.DeploymentManager;
-import org.jboss.deployers.spi.management.deploy.DeploymentProgress;
-import org.jboss.jopr.jsfunit.EmbjoprTestCase;
-import org.jboss.managed.api.ComponentType;
-import org.jboss.managed.api.DeploymentTemplateInfo;
-import org.jboss.managed.api.ManagedComponent;
-import org.jboss.managed.api.ManagedProperty;
-import org.jboss.metatype.api.values.MetaValue;
-import org.jboss.metatype.api.values.MetaValueFactory;
-import org.jboss.profileservice.spi.ProfileKey;
-import org.jboss.profileservice.spi.ProfileService;
-import org.jboss.virtual.VFS;
-
-/**
- * @author <a href="mailto:alex@jboss.org">Alexey Loubyansky</a>
- * @version <tt>$Revision: 87016 $</tt>
- */
-public abstract class AbstractProfileServiceTest
- extends EmbjoprTestCase
-{
-
- /** We use the default profile, defined by DeploymentManager to deploy apps. */
- public static final ProfileKey defaultProfile = new ProfileKey(ProfileKey.DEFAULT);
-
- protected ManagementView activeView;
- protected DeploymentManager deployMgr;
- private MetaValueFactory metaValueFactory;
-
- public AbstractProfileServiceTest(String name){
- //super(name);
- super();
- }
- public AbstractProfileServiceTest(){
- super();
- }
-
- /**
- * @return the ProfileKey.name to use when loading the profile
- */
- protected String getProfileName()
- {
- return null;
- }
-
- protected ProfileKey getProfileKey()
- {
- if(getProfileName() == null)
- return defaultProfile;
-
- return new ProfileKey(getProfileName());
- }
-
- protected void removeDeployment(String deployment)
- throws Exception
- {
- String names[] = new String[] {deployment};
- DeploymentManager deployMgr = getDeploymentManager();
- try
- {
- DeploymentProgress progress = deployMgr.stop(names);
- progress.run();
- assertFalse("failed: " + progress.getDeploymentStatus().getFailure(), progress.getDeploymentStatus().isFailed());
- }
- finally
- {
- DeploymentProgress progress = deployMgr.remove(names);
- progress.run();
- assertFalse("failed: " + progress.getDeploymentStatus().getFailure(), progress.getDeploymentStatus().isFailed());
- }
- }
-
- protected void createComponentTest(String templateName,
- Map<String, MetaValue> propValues,
- String deploymentName,
- ComponentType componentType, String componentName)
- throws Exception
- {
- createComponentTest(templateName, propValues, deploymentName, componentType, componentName, true);
- }
-
- protected void createComponentTest(String templateName,
- Map<String, MetaValue> propValues,
- String deploymentName,
- ComponentType componentType, String componentName,
- boolean processChanges)
- throws Exception
- {
- Set<String> removedPropNames = Collections.emptySet();
- createComponentTest(templateName, propValues, removedPropNames,
- deploymentName, componentType, componentName, processChanges);
- }
- protected void createComponentTest(String templateName,
- Map<String, MetaValue> propValues,
- Set<String> removedPropNames,
- String deploymentName,
- ComponentType componentType, String componentName,
- boolean processChanges)
- throws Exception
- {
- ManagementView mgtView = getManagementView();
- DeploymentTemplateInfo info = mgtView.getTemplate(templateName);
- assertNotNull("template " + templateName + " found", info);
- Map<String, ManagedProperty> props = info.getProperties();
- for(String propName : propValues.keySet())
- {
- ManagedProperty prop = props.get(propName);
- log.debug("createComponentTest("+propName+") before: "+prop.getValue());
- assertNotNull("property " + propName + " found in template " + templateName, prop);
- prop.setValue(propValues.get(propName));
- log.debug("createComponentTest("+propName+") after: "+prop.getValue());
- }
- for(String propName : removedPropNames)
- {
- ManagedProperty prop = props.get(propName);
- prop.setRemoved(true);
- log.debug("removed property: "+propName);
- }
-
- mgtView.applyTemplate(deploymentName, info);
- if(processChanges)
- {
- mgtView.process();
-
- // reload the view
- activeView = null;
- mgtView = getManagementView();
- ManagedComponent dsMC = getManagedComponent(mgtView, componentType, componentName);
- assertNotNull(dsMC);
-
- Set<String> mcPropNames = new HashSet<String>(dsMC.getPropertyNames());
- for(String propName : propValues.keySet())
- {
- ManagedProperty prop = dsMC.getProperty(propName);
- assertNotNull(prop);
- Object propValue = prop.getValue();
- Object expectedValue = propValues.get(propName);
- assertEquals(prop.getName(), expectedValue, propValue);
-
- mcPropNames.remove(propName);
- }
-
- if(!mcPropNames.isEmpty())
- {
- log.warn(getName() + "> untested properties: " + mcPropNames);
- }
- }
- }
-
- /**
- * Obtain the ProfileService.ManagementView
- * @return
- * @throws Exception
- */
- protected ManagementView getManagementView()
- throws Exception
- {
- if( activeView == null )
- {
- InitialContext ctx = getInitialContext();
- ProfileService ps = (ProfileService) ctx.lookup("ProfileService");
- activeView = ps.getViewManager();
- // Init the VFS to setup the vfs* protocol handlers
- VFS.init();
- }
- // Reload
- activeView.load();
- return activeView;
- }
- /**
- * Obtain the ProfileService.ManagementView
- * @return
- * @throws Exception
- */
- protected DeploymentManager getDeploymentManager()
- throws Exception
- {
- if( deployMgr == null )
- {
- InitialContext ctx = getInitialContext();
- ProfileService ps = (ProfileService) ctx.lookup("ProfileService");
- deployMgr = ps.getDeploymentManager();
- deployMgr.loadProfile(getProfileKey());
- // Init the VFS to setup the vfs* protocol handlers
- VFS.init();
- }
- return deployMgr;
- }
-
- /**
- * Locate the given ComponentType with the given component name.
- *
- * @param mgtView -
- * @return the matching ManagedComponent if found, null otherwise
- * @throws Exception
- */
- protected ManagedComponent getManagedComponent(ManagementView mgtView, ComponentType type, String name)
- throws Exception
- {
- Set<ManagedComponent> comps = mgtView.getComponentsForType(type);
- ManagedComponent mc = null;
- for (ManagedComponent comp : comps)
- {
- String cname = comp.getName();
- if( cname.endsWith(name) )
- {
- mc = comp;
- break;
- }
- }
- return mc;
- }
-
- protected MetaValueFactory getMetaValueFactory()
- {
- if(metaValueFactory == null)
- metaValueFactory = MetaValueFactory.getInstance();
- return metaValueFactory;
- }
-
- InitialContext getInitialContext() throws NamingException{
- return new InitialContext();
- }
-
-}
Copied: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java (from rev 568, trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/AbstractProfileServiceTest.java)
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java (rev 0)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/as5/app/ear/ProfileServiceTest.java 2009-07-22 19:23:36 UTC (rev 575)
@@ -0,0 +1,285 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.jopr.jsfunit.as5.app.ear;
+
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Map;
+import java.util.Set;
+
+import javax.naming.InitialContext;
+
+import javax.naming.NamingException;
+import org.jboss.deployers.spi.management.ManagementView;
+import org.jboss.deployers.spi.management.deploy.DeploymentManager;
+import org.jboss.deployers.spi.management.deploy.DeploymentProgress;
+import org.jboss.jopr.jsfunit.EmbjoprTestCase;
+import org.jboss.jopr.jsfunit.util.jaas.JaasUtils;
+import org.jboss.managed.api.ComponentType;
+import org.jboss.managed.api.DeploymentTemplateInfo;
+import org.jboss.managed.api.ManagedComponent;
+import org.jboss.managed.api.ManagedProperty;
+import org.jboss.metatype.api.values.MetaValue;
+import org.jboss.metatype.api.values.MetaValueFactory;
+import org.jboss.profileservice.spi.ProfileKey;
+import org.jboss.profileservice.spi.ProfileService;
+import org.jboss.virtual.VFS;
+
+
+
+/**
+ * @author Ondrej Zizka, original class by Alexey Loubyansky
+ */
+public class ProfileServiceTest
+ extends EmbjoprTestCase
+{
+
+ /** We use the default profile, defined by DeploymentManager to deploy apps. */
+ public static final ProfileKey defaultProfile = new ProfileKey(ProfileKey.DEFAULT);
+
+ protected ManagementView activeView;
+ protected DeploymentManager deployMgr;
+ private MetaValueFactory metaValueFactory;
+
+ public ProfileServiceTest(String name){
+ super();
+ }
+ public ProfileServiceTest(){
+ super();
+ }
+
+
+ /**
+ * List the contents of ProfileService.
+ */
+ public void testProfileServiceListContent() throws NamingException, Exception{
+ ManagementView managementView = JaasUtils.getInstance().getManagementView();
+
+ log.info("List of ProfileService contents (default profile):");
+
+ StringBuilder sb = new StringBuilder(4*1024);
+ for( ComponentType type : managementView.getComponentTypes() ){
+ sb.append(" * Type: ").append(type.toString()).append("\n");
+ for( ManagedComponent component : managementView.getComponentsForType(type) ){
+ sb.append(" * Component: ").append(component.toString()).append("\n");
+ }
+ }
+
+ log.info(sb.toString());
+ }
+
+
+
+
+
+ /**
+ * @return the ProfileKey.name to use when loading the profile
+ */
+ protected String getProfileName(){ return null; }
+
+ protected ProfileKey getProfileKey()
+ {
+ if(getProfileName() == null)
+ return defaultProfile;
+
+ return new ProfileKey(getProfileName());
+ }
+
+ protected void removeDeployment(String deployment)
+ throws Exception
+ {
+ String names[] = new String[] {deployment};
+ DeploymentManager deployMgr_ = getDeploymentManager();
+ try
+ {
+ DeploymentProgress progress = deployMgr_.stop(names);
+ progress.run();
+ assertFalse("failed: " + progress.getDeploymentStatus().getFailure(), progress.getDeploymentStatus().isFailed());
+ }
+ finally
+ {
+ DeploymentProgress progress = deployMgr_.remove(names);
+ progress.run();
+ assertFalse("failed: " + progress.getDeploymentStatus().getFailure(), progress.getDeploymentStatus().isFailed());
+ }
+ }
+
+ protected void createComponentTest(String templateName,
+ Map<String, MetaValue> propValues,
+ String deploymentName,
+ ComponentType componentType, String componentName)
+ throws Exception
+ {
+ createComponentTest(templateName, propValues, deploymentName, componentType, componentName, true);
+ }
+
+ protected void createComponentTest(String templateName,
+ Map<String, MetaValue> propValues,
+ String deploymentName,
+ ComponentType componentType, String componentName,
+ boolean processChanges)
+ throws Exception
+ {
+ Set<String> removedPropNames = Collections.emptySet();
+ createComponentTest(templateName, propValues, removedPropNames,
+ deploymentName, componentType, componentName, processChanges);
+ }
+ protected void createComponentTest(String templateName,
+ Map<String, MetaValue> propValues,
+ Set<String> removedPropNames,
+ String deploymentName,
+ ComponentType componentType, String componentName,
+ boolean processChanges)
+ throws Exception
+ {
+ ManagementView mgtView = getManagementView();
+ DeploymentTemplateInfo info = mgtView.getTemplate(templateName);
+ assertNotNull("template " + templateName + " found", info);
+ Map<String, ManagedProperty> props = info.getProperties();
+ for(String propName : propValues.keySet())
+ {
+ ManagedProperty prop = props.get(propName);
+ log.debug("createComponentTest("+propName+") before: "+prop.getValue());
+ assertNotNull("property " + propName + " found in template " + templateName, prop);
+ prop.setValue(propValues.get(propName));
+ log.debug("createComponentTest("+propName+") after: "+prop.getValue());
+ }
+ for(String propName : removedPropNames)
+ {
+ ManagedProperty prop = props.get(propName);
+ prop.setRemoved(true);
+ log.debug("removed property: "+propName);
+ }
+
+ mgtView.applyTemplate(deploymentName, info);
+ if(processChanges)
+ {
+ mgtView.process();
+
+ // reload the view
+ activeView = null;
+ mgtView = getManagementView();
+ ManagedComponent dsMC = getManagedComponent(mgtView, componentType, componentName);
+ assertNotNull(dsMC);
+
+ Set<String> mcPropNames = new HashSet<String>(dsMC.getPropertyNames());
+ for(String propName : propValues.keySet())
+ {
+ ManagedProperty prop = dsMC.getProperty(propName);
+ assertNotNull(prop);
+ Object propValue = prop.getValue();
+ Object expectedValue = propValues.get(propName);
+ assertEquals(prop.getName(), expectedValue, propValue);
+
+ mcPropNames.remove(propName);
+ }
+
+ if(!mcPropNames.isEmpty())
+ {
+ log.warn(getName() + "> untested properties: " + mcPropNames);
+ }
+ }
+ }
+
+ /**
+ * Obtain the ProfileService.ManagementView
+ * @return
+ * @throws Exception
+ */
+ protected ManagementView getManagementView()
+ throws Exception
+ {
+ /*
+ if( activeView == null )
+ {
+ InitialContext ctx = getInitialContext();
+ ProfileService ps = (ProfileService) ctx.lookup("ProfileService");
+ activeView = ps.getViewManager();
+ // Init the VFS to setup the vfs* protocol handlers
+ VFS.init();
+ }
+ // Reload
+ activeView.load();
+ return activeView;
+ /**/
+
+ return JaasUtils.getInstance().getManagementView();
+ }
+ /**
+ * Obtain the ProfileService.ManagementView
+ * @return
+ * @throws Exception
+ */
+ protected DeploymentManager getDeploymentManager()
+ throws Exception
+ {
+ /*
+ if( deployMgr == null )
+ {
+ InitialContext ctx = getInitialContext();
+ ProfileService ps = (ProfileService) ctx.lookup("ProfileService");
+ deployMgr = ps.getDeploymentManager();
+ deployMgr.loadProfile(getProfileKey());
+ // Init the VFS to setup the vfs* protocol handlers
+ VFS.init();
+ }
+ return deployMgr;
+ /**/
+ return JaasUtils.getInstance().getDeploymentManager();
+ }
+
+ /**
+ * Locate the given ComponentType with the given component name.
+ *
+ * @param mgtView -
+ * @return the matching ManagedComponent if found, null otherwise
+ * @throws Exception
+ */
+ protected ManagedComponent getManagedComponent(ManagementView mgtView, ComponentType type, String name)
+ throws Exception
+ {
+ Set<ManagedComponent> comps = mgtView.getComponentsForType(type);
+ ManagedComponent mc = null;
+ for (ManagedComponent comp : comps)
+ {
+ String cname = comp.getName();
+ if( cname.endsWith(name) )
+ {
+ mc = comp;
+ break;
+ }
+ }
+ return mc;
+ }
+
+ protected MetaValueFactory getMetaValueFactory()
+ {
+ if(metaValueFactory == null)
+ metaValueFactory = MetaValueFactory.getInstance();
+ return metaValueFactory;
+ }
+
+ InitialContext getInitialContext() throws NamingException{
+ return new InitialContext();
+ }
+
+}
15 years, 5 months
EMBJOPR SVN: r574 - trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit.
by embjopr-commits@lists.jboss.org
Author: ozizka(a)redhat.com
Date: 2009-07-22 12:20:31 -0400 (Wed, 22 Jul 2009)
New Revision: 574
Modified:
trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbjoprTestCase.java
Log:
* JAAS security added to DatasourceOperationsTest
Modified: trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbjoprTestCase.java
===================================================================
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbjoprTestCase.java 2009-07-21 23:13:12 UTC (rev 573)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/EmbjoprTestCase.java 2009-07-22 16:20:31 UTC (rev 574)
@@ -1001,7 +1001,7 @@
* @param deployment - the deployment we are interested in
*/
protected boolean isDeployed(String deployment) throws Exception {
- return isDeployed(deployment, false);
+ return isDeployed(deployment, true);
}
/**
* Return whether or not the given deployment is deployed.
15 years, 5 months
EMBJOPR SVN: r573 - trunk.
by embjopr-commits@lists.jboss.org
Author: ips
Date: 2009-07-21 19:13:12 -0400 (Tue, 21 Jul 2009)
New Revision: 573
Modified:
trunk/pom.xml
Log:
switch back to snapshot deps now that release is complete
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2009-07-21 23:11:42 UTC (rev 572)
+++ trunk/pom.xml 2009-07-21 23:13:12 UTC (rev 573)
@@ -25,7 +25,7 @@
<parent>
<groupId>org.rhq</groupId>
<artifactId>rhq-parent</artifactId>
- <version>1.3.0.EmbJopr.1_3_0-2</version>
+ <version>1.3.0-SNAPSHOT</version>
</parent>
<groupId>org.jboss.jopr</groupId>
@@ -64,9 +64,9 @@
<!-- dependency versions -->
<jaxb-api.version>2.1</jaxb-api.version>
<jaxb-impl.version>2.1.6</jaxb-impl.version>
- <jopr.version>2.3.0.EmbJopr.1.3.0-2</jopr.version>
+ <jopr.version>2.3.0-SNAPSHOT</jopr.version>
<richfaces.version>3.3.0.GA</richfaces.version>
- <rhq.version>1.3.0.EmbJopr.1_3_0-2</rhq.version>
+ <rhq.version>1.3.0-SNAPSHOT</rhq.version>
<seam.version>2.1.0.SP1</seam.version>
<seam.embedded.version>beta3.SP3</seam.embedded.version>
<!-- This is a special patched version of not-yet-released Facelets 1.1.15,
@@ -125,7 +125,7 @@
<module>core</module>
<module>jbas4</module>
<module>jbas5</module>
- <!--<module>jsfunit</module>-->
+ <module>jsfunit</module>
</modules>
<repositories>
15 years, 5 months
EMBJOPR SVN: r572 - in trunk: core and 2 other directories.
by embjopr-commits@lists.jboss.org
Author: ips
Date: 2009-07-21 19:11:42 -0400 (Tue, 21 Jul 2009)
New Revision: 572
Modified:
trunk/core/pom.xml
trunk/jbas4/pom.xml
trunk/jbas5/pom.xml
trunk/pom.xml
Log:
[maven-release-plugin] prepare for next development iteration
Modified: trunk/core/pom.xml
===================================================================
--- trunk/core/pom.xml 2009-07-21 23:11:29 UTC (rev 571)
+++ trunk/core/pom.xml 2009-07-21 23:11:42 UTC (rev 572)
@@ -23,7 +23,7 @@
<parent>
<groupId>org.jboss.jopr</groupId>
<artifactId>jopr-embedded-parent</artifactId>
- <version>1.3.0.Beta2</version>
+ <version>1.3.0-SNAPSHOT</version>
</parent>
<groupId>org.jboss.jopr</groupId>
@@ -35,8 +35,8 @@
</description>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/core</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/core</developerConnection>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/trunk/core/</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/trunk/core/</developerConnection>
</scm>
<properties>
Modified: trunk/jbas4/pom.xml
===================================================================
--- trunk/jbas4/pom.xml 2009-07-21 23:11:29 UTC (rev 571)
+++ trunk/jbas4/pom.xml 2009-07-21 23:11:42 UTC (rev 572)
@@ -5,7 +5,7 @@
<parent>
<groupId>org.jboss.jopr</groupId>
<artifactId>jopr-embedded-parent</artifactId>
- <version>1.3.0.Beta2</version>
+ <version>1.3.0-SNAPSHOT</version>
</parent>
<groupId>org.jboss.jopr</groupId>
@@ -14,8 +14,8 @@
<name>JBossAS 4.x Administration Console</name>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/j...</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/jbas4</developerConnection>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/trunk/jbas4/</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/trunk/jbas4/</developerConnection>
</scm>
<properties>
Modified: trunk/jbas5/pom.xml
===================================================================
--- trunk/jbas5/pom.xml 2009-07-21 23:11:29 UTC (rev 571)
+++ trunk/jbas5/pom.xml 2009-07-21 23:11:42 UTC (rev 572)
@@ -5,7 +5,7 @@
<parent>
<groupId>org.jboss.jopr</groupId>
<artifactId>jopr-embedded-parent</artifactId>
- <version>1.3.0.Beta2</version>
+ <version>1.3.0-SNAPSHOT</version>
</parent>
<groupId>org.jboss.jopr</groupId>
@@ -14,8 +14,8 @@
<name>JBossAS 5.x Administration Console</name>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/j...</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/jbas5</developerConnection>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/trunk/jbas5/</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/trunk/jbas5/</developerConnection>
</scm>
<properties>
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2009-07-21 23:11:29 UTC (rev 571)
+++ trunk/pom.xml 2009-07-21 23:11:42 UTC (rev 572)
@@ -30,7 +30,7 @@
<groupId>org.jboss.jopr</groupId>
<artifactId>jopr-embedded-parent</artifactId>
- <version>1.3.0.Beta2</version>
+ <version>1.3.0-SNAPSHOT</version>
<packaging>pom</packaging>
<name>Embedded Jopr</name>
<description>a web application that provides administration and monitoring of the app server instance to which it is deployed</description>
@@ -42,8 +42,8 @@
</organization>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2</developerConnection>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/trunk/</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/trunk/</developerConnection>
</scm>
<issueManagement>
15 years, 5 months
EMBJOPR SVN: r571 - tags.
by embjopr-commits@lists.jboss.org
Author: ips
Date: 2009-07-21 19:11:29 -0400 (Tue, 21 Jul 2009)
New Revision: 571
Added:
tags/EmbJopr_1_3_0_Beta2/
Log:
[maven-scm] copy for tag EmbJopr_1_3_0_Beta2
Copied: tags/EmbJopr_1_3_0_Beta2 (from rev 570, trunk)
15 years, 5 months
EMBJOPR SVN: r570 - in trunk: core and 2 other directories.
by embjopr-commits@lists.jboss.org
Author: ips
Date: 2009-07-21 19:11:18 -0400 (Tue, 21 Jul 2009)
New Revision: 570
Modified:
trunk/core/pom.xml
trunk/jbas4/pom.xml
trunk/jbas5/pom.xml
trunk/pom.xml
Log:
[maven-release-plugin] prepare release EmbJopr_1_3_0_Beta2
Modified: trunk/core/pom.xml
===================================================================
--- trunk/core/pom.xml 2009-07-21 23:08:27 UTC (rev 569)
+++ trunk/core/pom.xml 2009-07-21 23:11:18 UTC (rev 570)
@@ -23,7 +23,7 @@
<parent>
<groupId>org.jboss.jopr</groupId>
<artifactId>jopr-embedded-parent</artifactId>
- <version>1.3.0-SNAPSHOT</version>
+ <version>1.3.0.Beta2</version>
</parent>
<groupId>org.jboss.jopr</groupId>
@@ -35,8 +35,8 @@
</description>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/trunk/core/</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/trunk/core/</developerConnection>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/core</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/core</developerConnection>
</scm>
<properties>
Modified: trunk/jbas4/pom.xml
===================================================================
--- trunk/jbas4/pom.xml 2009-07-21 23:08:27 UTC (rev 569)
+++ trunk/jbas4/pom.xml 2009-07-21 23:11:18 UTC (rev 570)
@@ -5,7 +5,7 @@
<parent>
<groupId>org.jboss.jopr</groupId>
<artifactId>jopr-embedded-parent</artifactId>
- <version>1.3.0-SNAPSHOT</version>
+ <version>1.3.0.Beta2</version>
</parent>
<groupId>org.jboss.jopr</groupId>
@@ -14,8 +14,8 @@
<name>JBossAS 4.x Administration Console</name>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/trunk/jbas4/</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/trunk/jbas4/</developerConnection>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/j...</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/jbas4</developerConnection>
</scm>
<properties>
Modified: trunk/jbas5/pom.xml
===================================================================
--- trunk/jbas5/pom.xml 2009-07-21 23:08:27 UTC (rev 569)
+++ trunk/jbas5/pom.xml 2009-07-21 23:11:18 UTC (rev 570)
@@ -5,7 +5,7 @@
<parent>
<groupId>org.jboss.jopr</groupId>
<artifactId>jopr-embedded-parent</artifactId>
- <version>1.3.0-SNAPSHOT</version>
+ <version>1.3.0.Beta2</version>
</parent>
<groupId>org.jboss.jopr</groupId>
@@ -14,8 +14,8 @@
<name>JBossAS 5.x Administration Console</name>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/trunk/jbas5/</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/trunk/jbas5/</developerConnection>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/j...</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2/jbas5</developerConnection>
</scm>
<properties>
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2009-07-21 23:08:27 UTC (rev 569)
+++ trunk/pom.xml 2009-07-21 23:11:18 UTC (rev 570)
@@ -30,7 +30,7 @@
<groupId>org.jboss.jopr</groupId>
<artifactId>jopr-embedded-parent</artifactId>
- <version>1.3.0-SNAPSHOT</version>
+ <version>1.3.0.Beta2</version>
<packaging>pom</packaging>
<name>Embedded Jopr</name>
<description>a web application that provides administration and monitoring of the app server instance to which it is deployed</description>
@@ -42,8 +42,8 @@
</organization>
<scm>
- <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/trunk/</connection>
- <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/trunk/</developerConnection>
+ <connection>scm:svn:http://anonsvn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2</connection>
+ <developerConnection>scm:svn:https://svn.jboss.org/repos/embjopr/tags/EmbJopr_1_3_0_Beta2</developerConnection>
</scm>
<issueManagement>
15 years, 5 months
--- trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/EmbJoprTestToolkit.java 2009-07-23 18:24:30 UTC (rev 579)
+++ trunk/jsfunit/src/test/java/org/jboss/jopr/jsfunit/util/EmbJoprTestToolkit.java 2009-07-23 21:21:07 UTC (rev 580)
@@ -30,11 +30,13 @@
import javax.management.MBeanServer;
import javax.management.ObjectName;
import javax.servlet.http.HttpServletRequest;
+import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.math.NumberUtils;
import org.jboss.jopr.jsfunit.AppConstants;
import org.jboss.jopr.jsfunit.AppConstants.DeployableTypes;
import org.jboss.jopr.jsfunit.DebugUtils;
+import org.jboss.jopr.jsfunit.EmbJoprTestConstants;
import org.jboss.jopr.jsfunit.EmbjoprTestCase;
import org.jboss.jsfunit.jsfsession.*;
import org.jboss.logging.Logger;
@@ -677,6 +679,7 @@
+
/**
* Inner class for manipulation with tab content box.
*/
@@ -727,8 +730,8 @@
return null;
}
}
-
- return new ContentTable(tableElement);
+
+ return new ContentTable(tableElement, headerText);
}
/**
@@ -899,29 +902,60 @@
}
+
+ /**
+ * Returns the unformatted table (eg. General Properties and Traits).
+ */
+ public ContentInfoTable getTableUnformatted(String tableHeader) throws EmbJoprTestException {
+ ContentTable table = getTabMenu().getTabContentBox().getTableUnderHeader(tableHeader);
+ ContentInfoTable traitsTable = getTabMenu().getTabContentBox().getContentInfoTable( table.getElement() );
+ return traitsTable;
+ }
+
+
}// inner class TabContentBox
+
+
+
+
/**
- * Contains convenience methods for accessing content tables in EmbJopr.
+ * Contains convenience methods for accessing tables in EmbJopr.
+ * Works with any HTML table.
*/
public class ContentTable {
public static final String ID_CATEGORY_DATA_TABLE = "categorySummaryForm:dataTable";
public static final String ID_RESOURCE_DATA_TABLE = "resourceSummaryForm:dataTable";
-
+
+ /** HTML element of this table. */
+ public HtmlTable getElement() { return this.element; }
protected HtmlTable element;
- public HtmlTable getElement() { return element; }
+ /** Name of the table. Usualy header above the table is used. */
+ public String getTableName() { return this.name; }
+ protected String name;
+
+
/**
* Creates a data table wrapper for the given table element.
*/
- public ContentTable( HtmlTable element ) {
+ public ContentTable( HtmlTable element ) { init(element, null); }
+
+ /**
+ * Creates a data table wrapper for the given table element and stores it's name.
+ */
+ public ContentTable( HtmlTable element, String tableName ) { init(element, tableName); }
+
+ private void init( HtmlTable element, String tableName ){
if( null == element )
throw new IllegalArgumentException("null given as element for ContentTable.");
this.element = element;
+ this.name = tableName;
}
+
/**
* Creates a data table wrapper for first found element with one of these IDs:
* ID_CATEGORY_DATA_TABLE, ID_RESOURCE_DATA_TABLE
@@ -1056,8 +1090,9 @@
}
/**
- * Creates a list of columns headers
- * and a label => col index map.
+ * Creates a list of columns headers and a label => col index map.
+ * Works for tables which have column headers,
+ * ie. they have TH elements in the first row.
*/
public void analyzeColumns() throws HtmlElementNotFoundException
{
@@ -1098,6 +1133,9 @@
* 1) Table does not have column headers
* 2) No header with such name was found.
*
+ * Works for tables which have column headers,
+ * ie. they have TH elements in the first row.
+ *
* @param colName
* @return
* @throws org.jboss.jopr.jsfunit.exceptions.HtmlElementNotFoundException
@@ -1116,6 +1154,10 @@
/**
* Creates a properties using values from this table.
+ *
+ * Works for tables which have column headers,
+ * ie. they have TH elements in the first row.
+ *
* @param keyColName Name of column containing the key (e.g. "Name").
* @param valueColName Name of column containing the value (e.g. "Value").
*/
@@ -1135,14 +1177,40 @@
return props;
}
+ public Properties getProperties() throws HtmlElementNotFoundException {
+ return this.getProperties(EmbJoprTestConstants.COL_PROP_NAME, EmbJoprTestConstants.COL_PROP_VALUE);
+ }
+
+ /**
+ * Checks that name/value pairs in this table mach the given values.
+ * @throws EmbJoprTestException if any of given values does not match with the value in this table.
+ */
+ public void checkValues( Properties propsExpected ) throws EmbJoprTestException {
+
+ // Get this tables properties. Different table types can override this.
+ Properties propsActual = this.getProperties();
+
+ // Check all the properties.
+ for( Object key : propsExpected.keySet() ){
+ String propName = (String)key;
+ String exp = propsExpected.getProperty(propName);
+ String act = propsActual.getProperty(propName);
+ if( !StringUtils.equals( exp, act ) ){
+ // If this table has a name, use it in the exception message.
+ String msgFormat = (null == this.getTableName() ? "%2$s: expected '%3$s', actual '%4$s'." : "%s - %s: expected '%s', actual '%s'.");
+ throw new EmbJoprTestException( String.format(msgFormat, this.getTableName(), propName, exp, act) );
+ }
+ }
+ }
+
+
}// inner class ContentTable
-
/**
* Creates a data table wrapper for first found element with one of these IDs:
* ID_CATEGORY_DATA_TABLE, ID_RESOURCE_DATA_TABLE
@@ -1160,7 +1228,8 @@
/**
* Provides extra method that parses text-like info table (with one column).
*/
public class ContentInfoTable extends ContentTable {
@@ -1169,7 +1238,10 @@
}
/**
- * Parses the content of the table properties.
+ * Parses the content of the table.
+ * Works with text-like info table (with one column) -
+ * usualy Traits tables have this structure.
+ *
* @returns Set of properties extracted from rows
* whose plain text has the 'Name: Value' format.
*/
@@ -1193,6 +1265,7 @@
return props;
}
+
}// inner class ContentInfoTable
/**
Added: trunk/jsfunit/testdata/jbcache/JBossCacheTest-by-fdrabek.ear
===================================================================
(Binary files differ)
Property changes on: trunk/jsfunit/testdata/jbcache/JBossCacheTest-by-fdrabek.ear
___________________________________________________________________
Name: svn:mime-type
+ application/octet-stream
Added: trunk/jsfunit/testdata/jbcache/JBossCacheTest-service.xml
===================================================================
@@ -1160,7 +1228,8 @@
/**
- * Provides extra method that parses text-like info table (with one column).
+ * Provides extra method that parses text-like info table (with one column) -
+ * usualy Traits tables have this structure.
*/
public class ContentInfoTable extends ContentTable {